@@ -1,7 +1,4 @@
-static int trace_sysnum(void)
-{
-	return do_peekuser(0);	/* register r0 */
-}
+#define trace_sysnum_puser 0	/* register r0 */
 
 static long trace_raw_ret(void *vregs)
 {
@@ -9,6 +6,11 @@ static long trace_raw_ret(void *vregs)
 	return regs->r0;
 }
 
+static void trace_set_ret(void *vregs, int err)
+{
+	do_pokeuser(0, -err);	/* register r0 */
+}
+
 static unsigned long trace_arg(void *vregs, int num)
 {
 	trace_regs *regs = vregs;
